@@ -52,7 +52,7 @@ class Hidden(gobject.GObject):
     def __init__(self,comp,width,height,total_width=-1,total_height=-1):
         gobject.GObject.__init__(self)
 
-        if 'win' in sys.platform:
+        if 'win' == sys.platform[:3]:
             (self.readfd, self.writefd) = fract4dc.pipe()
         else:
             # This is the line that was screwing Windows up.. changed to be run only on Linux, for Windows, we want to do this in fract4dc..
